Error class final

Represents an error from the device in regards to location

Constructors

Error({required String message, required ErrorCode errorCode})
Creates an error with the given message and error code
const

Properties

errorCode → ErrorCode
The error code representing the type of error
final
hashCode → int
The hash code for this object.
no setteroverride
message → String
The textual message of the error
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

empty → const Error
No error
unknown → const Error
Represents an unknown error with no information from the device